@@ -56,6 +56,9 @@ extern Datum PGDLLEXPORT pgroonga_score(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_table_name(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_command(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_snippet_html(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_highlight_html(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_match_positions_byte(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_query_extract_keywords(PG_FUNCTION_ARGS);
 
 extern Datum PGDLLEXPORT pgroonga_match_term_text(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_match_term_text_array(PG_FUNCTION_ARGS);
